local fr = {}

-- Templates
fr.tpl_vars = {
  post = {
    -- It might not be really necessary to mention post/feed/log each time
    -- since those occur in different templates?
    -- This would make the french translated tags much cleaner, because the
    -- proper way to do this translation would be "auteur_de_l'article"
    -- (author_of_the_post).
    author = "{{ auteur_article }}",
    content = "{{ contenu_article }}",
    date = "{{ date_article }}",
    summary = "{{ résumé_article }}",
    -- This is not used in the templates.
    tags = "{{ tags_article }}",
    title = "{{ titre_article }}",
    url = "{{ url_article }}",
  },
  feed = {
    date = "{{ date_flux }}",
    url = "{{ url_flux }}",
  },
  index = {
    posts = "{{ articles }}",
  },
  log = {
    -- The concept of a "gemlog" does not have a French translation
    -- as far as I know, so I used 'capsule' instead of 'log'.
    author = "{{ auteur_capsule }}",
    subtitle = "{{ sous_titre_capsule }}",
    title = "{{ titre_capsule }}",
    log_url = "{{ url_capsule }}",
  },
}

fr.atom_header = [[<?xml version="1.0" encoding="UTF-8"?>
<feed xmlns="http://www.w3.org/2005/Atom">
  <title>{{ titre_capsule }}</title>
  <subtitle>{{ sous_titre_capsule }}</subtitle>
  <updated>{{ date_flux }}</updated>
  <author>
    <name>{{ auteur_capsule }}</name>
  </author>
  <id>{{ url_flux }}</id>
  <link href="{{ url_capsule }}" rel="alternate"/>
  <link href="{{ url_flux }}" rel="self" type="application/atom+xml"/>
]]

fr.atom_entry = [[
  <entry>
    <id>{{ url_article }}</id>
    <title>
      <![CDATA[{{ titre_article }}]] .. "]]>" .. [[

    </title>
    <updated>{{ date_article }}</updated>
    <author>
      <name>{{ auteur_article }}</name>
    </author>
    <link href="{{ url_article }}" rel="alternate"/>
    <summary>
      <![CDATA[{{ résumé_article }}]] .. "]]>" .. [[

    </summary>
    <content>
      <![CDATA[{{ contenu_article }}]] .. "]]>" .. [[

    </content>
  </entry>
]]

fr.atom_footer = [[</feed>]]

fr.post = [[---
date: {{ date_article }}
---

# {{ titre_article }}




## Liens

=> gemini:// lien
=> gemini:// lien (image)
=> https:// lien (https)]]

fr.index = [[
# {{ titre_capsule }}
{{ articles }}
]]

fr.page = [[
# {{ titre_article }}

## Titre de niveau 2
### Titre de niveau 3

Liste :

*
*
*

```
Texte préformaté
```


## Liens

=> gemini:// lien
=> gemini:// lien (image)
=> https:// lien (https)]]

-- App command options and messages output
-- These probably should always stay untranslated, because having a CLI's
-- entire command line change depending on the language would be a mess.
-- Imagine writing bash in french…
fr.opts = {
  config = "config",
  page = "page",
  post = "post",
  index = "index",
  publish = "publish",
  help = "help",
  version = "version",
}

fr.msgs = {
  add_gemtext = "Créé ",
  help = [[ [options] [capsule] [titre]

Options :

config                    Générer un dossier de configuration
page [capsule] [titre]    Ajouter une nouvelle page avec le titre fourni
post [capsule] [titre]    Ajouter un nouvel article avec le titre fourni
index                     Générer une page d'accueil et un flux d'articles
publish                   Générer les pages puis les publier via scp
help                      Afficher ce message d'aide
version                   Afficher les informations de version]],
  index = "Flux et page d'accueil créés.",
  load_config = [[Les fichiers de configuration ont été créés. Veuillez y
inscrire les valeurs correctes avant de continuer.
Les fichiers peuvent être trouvés dans :
]],
  publish = "Capsule publiée.",
}

fr.errs = {
  invalid_cap_id = "Erreur: Identifiant de capsule inconnu.",
}

return fr
